pub enum TextSelectionCoverage {
Bounded,
FromStart,
ToEnd,
Full,
}Expand description
How much of one participant participates in a window selection.
Variants
Bounded
Only the interval between this participant’s two endpoints is selected.
FromStart
The participant is selected from its beginning through its endpoint.
ToEnd
The participant is selected from its endpoint through its end.
Full
The entire participant lies between endpoints in other participants.