pub fn pointer_spring(cx: &App) -> SpringExpand description
The spring a hover pointer — the crosshair, highlight band or hover dot —
follows the hovered datum with: the active PlotMotion’s
pointer, which snaps unless a styled layer projects one.
pub fn pointer_spring(cx: &App) -> SpringThe spring a hover pointer — the crosshair, highlight band or hover dot —
follows the hovered datum with: the active PlotMotion’s
pointer, which snaps unless a styled layer projects one.