Module slider

Module slider 

Structs

Slider
An unstyled slider behavior root.
SliderIndicator
An unstyled slider indicator that records the value-mapping bounds.
SliderState
State of the Slider.
SliderThumb
An unstyled draggable slider thumb.
SliderTrack
An unstyled track that records the geometry used to map pointer positions.

Enums

SliderEvent
Events emitted by the SliderState.
SliderScale
The scale mode of the slider.
SliderValue
The value of the slider, can be a single value or a range of values.