pub enum SliderEvent {
Change(SliderValue),
Release(SliderValue),
}Expand description
Events emitted by the SliderState.
Variants
Change(SliderValue)
Emitted continuously while the slider value is being changed by the user.
Release(SliderValue)
Emitted once when the user releases the slider after a drag or click.