pub enum SliderValue {
Single(f32),
Range(f32, f32),
}Expand description
The value of the slider, can be a single value or a range of values.
- Can from a f32 value, which will be treated as a single value.
- Or from a (f32, f32) tuple, which will be treated as a range of values.
The default value is SliderValue::Single(0.0).
Variants
Implementations
Sourceimpl SliderValue
impl SliderValue