pub struct ButtonStyles { /* private fields */ }Expand description
Semantic styles supported by Button.
Implementations
Sourceimpl ButtonStyles
impl ButtonStyles
Sourcepub fn selected(self, build: impl FnOnce(StateStyle) -> StateStyle) -> Self
pub fn selected(self, build: impl FnOnce(StateStyle) -> StateStyle) -> Self
Refines the root style when the button is selected.
Sourcepub fn disabled(self, build: impl FnOnce(StateStyle) -> StateStyle) -> Self
pub fn disabled(self, build: impl FnOnce(StateStyle) -> StateStyle) -> Self
Refines the root style when the button is disabled.