pub struct CheckboxStyles { /* private fields */ }Expand description
Semantic styles supported by Checkbox.
Implementations
Sourceimpl CheckboxStyles
impl CheckboxStyles
Sourcepub fn checked(self, build: impl FnOnce(StateStyle) -> StateStyle) -> Self
pub fn checked(self, build: impl FnOnce(StateStyle) -> StateStyle) -> Self
Refines the root style when the checkbox is checked.
Sourcepub fn indeterminate(self, build: impl FnOnce(StateStyle) -> StateStyle) -> Self
pub fn indeterminate(self, build: impl FnOnce(StateStyle) -> StateStyle) -> Self
Refines the root style when the checkbox is indeterminate.
Sourcepub fn disabled(self, build: impl FnOnce(StateStyle) -> StateStyle) -> Self
pub fn disabled(self, build: impl FnOnce(StateStyle) -> StateStyle) -> Self
Refines the root style when the checkbox is disabled.