pub struct IndexPath {
pub section: usize,
pub row: usize,
pub column: usize,
}Expand description
Represents an index path in a list, which consists of a section index,
The default values for section, row, and column are all set to 0.
Fields
section: usizeThe section index.
row: usizeThe item index in the section.
column: usizeThe column index.
Implementations