pub struct Scrollbar { /* private fields */ }Expand description
Scrollbar control for scroll-area or a uniform-list.
Implementations
Sourceimpl Scrollbar
impl Scrollbar
Sourcepub fn new<H: ScrollbarHandle + Clone>(scroll_handle: &H) -> Self
pub fn new<H: ScrollbarHandle + Clone>(scroll_handle: &H) -> Self
Create a new scrollbar.
This will have both vertical and horizontal scrollbars.
Sourcepub fn horizontal<H: ScrollbarHandle + Clone>(scroll_handle: &H) -> Self
pub fn horizontal<H: ScrollbarHandle + Clone>(scroll_handle: &H) -> Self
Create with horizontal scrollbar.
Sourcepub fn vertical<H: ScrollbarHandle + Clone>(scroll_handle: &H) -> Self
pub fn vertical<H: ScrollbarHandle + Clone>(scroll_handle: &H) -> Self
Create with vertical scrollbar.
Sourcepub fn id(self, id: impl Into<ElementId>) -> Self
pub fn id(self, id: impl Into<ElementId>) -> Self
Set a specific element id, default is the Location::caller.
NOTE: In most cases, you don’t need to set a specific id for scrollbar.
Sourcepub fn mode(self, mode: ScrollbarMode) -> Self
pub fn mode(self, mode: ScrollbarMode) -> Self
Set the scrollbar show mode ScrollbarMode.
If unset, the current application theme projection is used.
Sourcepub fn scroll_size(self, scroll_size: Size<Pixels>) -> Self
pub fn scroll_size(self, scroll_size: Size<Pixels>) -> Self
Set a special scroll size of the content area, default is None.
Default will sync the content_size from scroll_handle.
Sourcepub fn viewport_bounds(self, bounds: Bounds<Pixels>) -> Self
pub fn viewport_bounds(self, bounds: Bounds<Pixels>) -> Self
Override the viewport bounds that this scrollbar overlays.
Most scroll containers should rely on the bounds reported by their scroll handle. Custom-painted viewports, such as the text editor, can use this when their visible bounds differ from the handle’s layout bounds.
Sourcepub fn viewport_from_layout(self) -> Self
pub fn viewport_from_layout(self) -> Self
Use the scrollbar element’s layout bounds as its viewport.
This is useful for composite widgets whose scrollbar viewport excludes fixed headers or columns and is therefore defined by a positioned overlay container rather than by the underlying scroll handle.
Sourcepub fn axis(self, axis: impl Into<ScrollbarAxis>) -> Self
pub fn axis(self, axis: impl Into<ScrollbarAxis>) -> Self
Set scrollbar axis.
pub fn styles( self, build: impl FnOnce(ScrollbarStyles) -> ScrollbarStyles, ) -> Self