pub struct TextSelectionEndpoint { /* private fields */ }Expand description
A selection endpoint anchored to a participant’s content coordinates.
Implementations
Sourceimpl TextSelectionEndpoint
impl TextSelectionEndpoint
Sourcepub const fn entity_id(&self) -> Option<EntityId>
pub const fn entity_id(&self) -> Option<EntityId>
Returns the participant which owns this endpoint, when it hit one.
Sourcepub const fn content_point(&self) -> Point<Pixels>
pub const fn content_point(&self) -> Point<Pixels>
Returns the participant-relative content point.
Sourcepub const fn content_key(&self) -> Option<TextSelectionContentKey>
pub const fn content_key(&self) -> Option<TextSelectionContentKey>
Returns participant-defined endpoint metadata captured when it hit a participant.