pub struct TextSelectionRun { /* private fields */ }Expand description
Laid-out text reported by a plain selection participant during paint.
Implementations
Sourceimpl TextSelectionRun
impl TextSelectionRun
Sourcepub fn new(
text: impl Into<SharedString>,
layout: TextLayout,
bounds: Bounds<Pixels>,
) -> Self
pub fn new( text: impl Into<SharedString>, layout: TextLayout, bounds: Bounds<Pixels>, ) -> Self
Creates a laid-out text run.
Sourcepub const fn with_document_order(self, document_order: u64) -> Self
pub const fn with_document_order(self, document_order: u64) -> Self
Sets the run’s logical order within the participant.
Sourcepub const fn document_order(&self) -> u64
pub const fn document_order(&self) -> u64
Returns the run’s logical order within its participant.
Sourcepub fn text(&self) -> &SharedString
pub fn text(&self) -> &SharedString
Returns the exact text used to produce the layout.
Sourcepub fn layout(&self) -> &TextLayout
pub fn layout(&self) -> &TextLayout
Returns the laid-out glyph geometry.