pub fn markdown(source: impl Into<SharedString>) -> TextViewExpand description
Create a new markdown text view with code location as id.
pub fn markdown(source: impl Into<SharedString>) -> TextViewCreate a new markdown text view with code location as id.