pub struct Definition {
pub position: Option<Position>,
pub url: String,
pub title: Option<String>,
pub identifier: String,
pub label: Option<String>,
}Expand description
Definition.
> | [a]: b
^^^^^^Fields
position: Option<Position>Positional info.
url: StringURL to the referenced resource.
title: Option<String>Advisory info for the resource, such as something that would be appropriate for a tooltip.
identifier: StringValue that can match another node.
identifier is a source value: character escapes and character references
are not parsed.
Its value must be normalized.
label: Option<String>label is a string value: it works just like title on a link or a
lang on code: character escapes and character references are parsed.
To normalize a value, collapse markdown whitespace ([\t\n\r ]+) to a
space, trim the optional initial and/or final space, and perform
case-folding.