pub struct ImageReference {
pub position: Option<Position>,
pub alt: String,
pub reference_kind: ReferenceKind,
pub identifier: String,
pub label: Option<String>,
}Expand description
Image reference.
> | ![a]
^^^^Fields
position: Option<Position>Positional info.
alt: StringEquivalent content for environments that cannot represent the node as intended.
reference_kind: ReferenceKindExplicitness of a reference.
identifier: StringValue that can match another node.
identifier is a source value: character escapes and character references
are not parsed.
Its value must be normalized.
label: Option<String>label is a string value: it works just like title on a link or a
lang on code: character escapes and character references are parsed.
To normalize a value, collapse markdown whitespace ([\t\n\r ]+) to a
space, trim the optional initial and/or final space, and perform
case-folding.