pub struct RadiusTokens {
pub none: Pixels,
pub sm: Pixels,
pub md: Pixels,
pub lg: Pixels,
pub xl: Pixels,
pub full: Pixels,
}Fields
none: Pixelssm: Pixelsmd: Pixelslg: Pixelsxl: Pixelsfull: PixelsTrait Implementations
Sourceimpl Clone for RadiusTokens
impl Clone for RadiusTokens
Sourcefn clone(&self) -> RadiusTokens
fn clone(&self) -> RadiusTokens
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RadiusTokens
Sourceimpl Debug for RadiusTokens
impl Debug for RadiusTokens
Sourceimpl Default for RadiusTokens
impl Default for RadiusTokens
Sourceimpl<'de> Deserialize<'de> for RadiusTokens
impl<'de> Deserialize<'de> for RadiusTokens
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RadiusTokens
impl JsonSchema for RadiusTokens
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RadiusTokens
impl PartialEq for RadiusTokens
Sourceimpl Serialize for RadiusTokens
impl Serialize for RadiusTokens
impl StructuralPartialEq for RadiusTokens