pub struct SemanticThemeTokens {
pub colors: ColorTokens,
pub radius: RadiusTokens,
pub spacing: SpacingTokens,
pub typography: TypographyTokens,
pub shadow: ShadowTokens,
}Fields
colors: ColorTokensradius: RadiusTokensspacing: SpacingTokenstypography: TypographyTokensshadow: ShadowTokensTrait Implementations
Sourceimpl Clone for SemanticThemeTokens
impl Clone for SemanticThemeTokens
Sourcefn clone(&self) -> SemanticThemeTokens
fn clone(&self) -> SemanticThemeTokens
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticThemeTokens
impl Debug for SemanticThemeTokens
Sourceimpl Default for SemanticThemeTokens
impl Default for SemanticThemeTokens
Sourcefn default() -> SemanticThemeTokens
fn default() -> SemanticThemeTokens
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SemanticThemeTokens
impl<'de> Deserialize<'de> for SemanticThemeTokens
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SemanticThemeTokens
impl JsonSchema for SemanticThemeTokens
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SemanticThemeTokens
impl PartialEq for SemanticThemeTokens
Sourceimpl Serialize for SemanticThemeTokens
impl Serialize for SemanticThemeTokens
impl StructuralPartialEq for SemanticThemeTokens