pub struct SpacingTokens {
pub xxs: Pixels,
pub xs: Pixels,
pub sm: Pixels,
pub md: Pixels,
pub lg: Pixels,
pub xl: Pixels,
pub xxl: Pixels,
}Fields
xxs: Pixelsxs: Pixelssm: Pixelsmd: Pixelslg: Pixelsxl: Pixelsxxl: PixelsTrait Implementations
Sourceimpl Clone for SpacingTokens
impl Clone for SpacingTokens
Sourcefn clone(&self) -> SpacingTokens
fn clone(&self) -> SpacingTokens
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SpacingTokens
Sourceimpl Debug for SpacingTokens
impl Debug for SpacingTokens
Sourceimpl Default for SpacingTokens
impl Default for SpacingTokens
Sourceimpl<'de> Deserialize<'de> for SpacingTokens
impl<'de> Deserialize<'de> for SpacingTokens
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SpacingTokens
impl JsonSchema for SpacingTokens
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SpacingTokens
impl PartialEq for SpacingTokens
Sourceimpl Serialize for SpacingTokens
impl Serialize for SpacingTokens
impl StructuralPartialEq for SpacingTokens