pub struct TypographyTokens {
pub sans: SharedString,
pub mono: SharedString,
pub xs: TextStyleToken,
pub sm: TextStyleToken,
pub md: TextStyleToken,
pub lg: TextStyleToken,
pub xl: TextStyleToken,
pub mono_md: TextStyleToken,
}Fields
sans: SharedStringmono: SharedStringxs: TextStyleTokensm: TextStyleTokenmd: TextStyleTokenlg: TextStyleTokenxl: TextStyleTokenmono_md: TextStyleTokenTrait Implementations
Sourceimpl Clone for TypographyTokens
impl Clone for TypographyTokens
Sourcefn clone(&self) -> TypographyTokens
fn clone(&self) -> TypographyTokens
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TypographyTokens
impl Debug for TypographyTokens
Sourceimpl Default for TypographyTokens
impl Default for TypographyTokens
Sourceimpl<'de> Deserialize<'de> for TypographyTokens
impl<'de> Deserialize<'de> for TypographyTokens
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TypographyTokens
impl JsonSchema for TypographyTokens
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TypographyTokens
impl PartialEq for TypographyTokens
Sourceimpl Serialize for TypographyTokens
impl Serialize for TypographyTokens
impl StructuralPartialEq for TypographyTokens