Module text

Module text 

Modules

markdown_ast
Re-export of the Markdown AST types used by custom parsers. markdown syntax tree: mdast.

Structs

CodeBlock
MarkdownExtensions
Registry for custom Markdown parsing and rendering.
MarkdownNode
A custom Markdown node produced by MarkdownExtensions.
MarkdownParseContext
Context passed to custom Markdown parsers.
TableData
Plain snapshot of a rendered Markdown table, passed to the crate::text::TextView::table_actions hook.
TextView
A text view that can render Markdown or HTML.
TextViewDefaults
Application-wide defaults for TextViews that do not provide explicit presentation or syntax-highlighting overrides.
TextViewLayoutState
TextViewPrepaintState
TextViewState
The state of a TextView.
TextViewStyle
TextViewStyle used to customize the style for super::TextView.

Enums

SelectionFormat
The format of the text returned by TextViewState::selected_text, which is also what copy writes to the clipboard.
Text

Traits

MarkdownPlugin
A reusable Markdown extension that parses and renders one custom node.
TextViewPlugin
A plugin that can configure a TextView.

Functions

html
Create a new html text view with code location as id.
markdown
Create a new markdown text view with code location as id.

Type Aliases

MarkdownBlockParserFn
Type for a custom Markdown block parser.
MarkdownBlockRenderFn
Type for a custom Markdown block renderer.