Modules
- markdown_
ast - Re-export of the Markdown AST types used by custom parsers. markdown syntax tree: mdast.
Structs
- Code
Block - Markdown
Extensions - Registry for custom Markdown parsing and rendering.
- Markdown
Node - A custom Markdown node produced by
MarkdownExtensions. - Markdown
Parse Context - Context passed to custom Markdown parsers.
- Table
Data - Plain snapshot of a rendered Markdown table, passed to the
crate::text::TextView::table_actionshook. - Text
View - A text view that can render Markdown or HTML.
- Text
View Defaults - Application-wide defaults for TextViews that do not provide explicit presentation or syntax-highlighting overrides.
- Text
View Layout State - Text
View Prepaint State - Text
View State - The state of a TextView.
- Text
View Style - TextViewStyle used to customize the style for
super::TextView.
Enums
- Selection
Format - The format of the text returned by
TextViewState::selected_text, which is also what copy writes to the clipboard. - Text
Traits
- Markdown
Plugin - A reusable Markdown extension that parses and renders one custom node.
- Text
View Plugin - A plugin that can configure a
TextView.
Functions
- html
- Create a new html text view with code location as id.
- markdown
- Create a new markdown text view with code location as id.
Type Aliases
- Markdown
Block Parser Fn - Type for a custom Markdown block parser.
- Markdown
Block Render Fn - Type for a custom Markdown block renderer.